        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 30 <br>1,2,4,6,7,9,10,11,12,13,14,15,19,20,21,23,24,25,26,27,29,30,32,34,35,36,37,39,41,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,3,5,8,16,17,18,22,28,31,33,38,40,42,43,44,45,46,47,48,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 30 <br>1,2,4,6,7,9,10,11,12,13,14,15,19,20,21,23,24,25,26,27,29,30,32,34,35,36,37,39,41,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,3,5,8,16,17,18,22,28,31,33,38,40,42,43,44,45,46,47,48,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 30 <br>1,2,4,6,7,9,10,11,12,13,14,15,19,20,21,23,24,25,26,27,29,30,32,34,35,36,37,39,41,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,3,5,8,16,17,18,22,28,31,33,38,40,42,43,44,45,46,47,48,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 30 <br>1,2,4,6,7,9,10,11,12,13,14,15,19,20,21,23,24,25,26,27,29,30,32,34,35,36,37,39,41,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,3,5,8,16,17,18,22,28,31,33,38,40,42,43,44,45,46,47,48,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 30 <br>1,2,4,6,7,9,10,11,12,13,14,15,19,20,21,23,24,25,26,27,29,30,32,34,35,36,37,39,41,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260519 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,3,5,8,16,17,18,22,28,31,33,38,40,42,43,44,45,46,47,48,50';}
}
